@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -37,7 +37,7 @@ MBoxMainWindow::MBoxMainWindow(const QString &filename, QWidget *parent)
     : QDialog(parent),
       mFileName(filename)
 {
-    setWindowTitle(i18n("Import mbox file"));
+    setWindowTitle(i18nc("@title:window", "Import mbox file"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     MBoxImporterKernel *kernel = new MBoxImporterKernel(this);
